#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @useDynLib coxstream, .registration = TRUE
#' @importFrom Rcpp evalCpp
#' @importFrom stats model.frame model.matrix model.response pnorm printCoefmat
## usethis namespace: end
NULL
